@@ -1,29 +1,14 @@
 #!/usr/bin/env python3
 
+
+
 from argparse import Namespace
 from pathlib import Path
 from sys import argv, stderr
 
-from hgen.injector import insert_prototypes
-from hgen.proto import get_prototypes
+from hgen.injector import create_header_prototypes, insert_prototypes
 from hgen.utils import create_parser, visualize
 
-
-def update_header_prototypes(args: Namespace):
-    prototypes: list[str] = []
-
-    dest_path = args.common / args.includes
-
-    for src in args.sources:
-        try:
-            src_path = args.common / src
-            visualize(dest_path, src_path)
-            prototypes.extend(get_prototypes(src_path))
-        except:
-            pass
-    insert_prototypes(dest_path, protos=prototypes)
-
-
 def main():
     parser = create_parser()
     if len(argv) == 1:
@@ -31,4 +16,10 @@ def main():
         exit()
 
     args = parser.parse_args()
-    update_header_prototypes(args)
+    dest_path = args.common / args.includes
+    common_path = args.common
+
+    prototypes: "list[str]" = create_header_prototypes(
+        args.sources, common_path, dest_path
+    )
+    insert_prototypes(dest_path, protos=prototypes)
