@@ -1,4 +1,4 @@
+from .arg_parsing import create_parser
 from .colors import cprint, cstr
 from .regexrules import RegexRules
-from .utils import get_lines_from, visualize
-from .arg_parsing import create_parser
\ No newline at end of file
+from .utils import TAB, get_lines_from, visualize
