@@ -1,11 +1,16 @@
 #!/usr/bin/env python3
 
 from pathlib import Path
-from . import cstr
 
-def get_lines_from(file: Path) -> 'list[str]':
+from hgen.utils.colors import cstr
+
+TAB = "\t"
+
+
+def get_lines_from(file: Path) -> "list[str]":
     return file.read_text().splitlines(keepends=False)
 
+
 def visualize(dest_path: Path, src_path: Path):
     cols = {"d": "", "s": ""}
     for n, path in (("d", dest_path), ("s", src_path)):
@@ -15,4 +20,4 @@ def visualize(dest_path: Path, src_path: Path):
             + cstr("yellow", f"{p.parent.name}/")
             + cstr("red", p.name)
         )
-    print(f"{cols['s']} -> {cols['d']}")
\ No newline at end of file
+    print(f"{cols['s']} -> {cols['d']}")
